@@ -2,6 +2,7 @@ from dataclasses import dataclass
 
 import numpy as np
 
+from ivory.core.run import Run
 from ivory.core.state import State
 
 
@@ -18,19 +19,18 @@ class Monitor(State):
         elif self.mode == "max":
             self.best_score = -np.inf
         else:
-            raise ValueError(f"mode must be 'min' or 'max': {self.mode} given.")
+            raise ValueError(f"Mode must be 'min' or 'max': {self.mode!r} given.")
 
     def __repr__(self):
         class_name = self.__class__.__name__
-        s = f"metric='{self.metric}', mode='{self.mode}'"
+        s = f"metric={self.metric!r}, mode={self.mode!r}"
         if self.best_epoch != -1:
             s += f", best_score={self.best_score:.3g}, best_epoch={self.best_epoch}"
         return f"{class_name}({s})"
 
-    def on_epoch_end(self, run):
+    def on_epoch_end(self, run: Run):
         if self.metric not in run.metrics:
-            msg = f"Metric '{self.metric}' not found. Available metrics are: "
-            msg += f"{run.metrics}"
+            msg = f"Metric {self.metric!r} not found. Available metrics: {run.metrics}"
             raise ValueError(msg)
         score = run.metrics[self.metric]
         if self.mode == "min":
