@@ -1,5 +1,5 @@
 import numpy as np
-from sklearn.model_selection import KFold, StratifiedKFold
+from sklearn.model_selection import GroupKFold, KFold, StratifiedKFold
 
 
 def fold_array(splitter, x, y=None, groups=None):
@@ -14,6 +14,11 @@ def kfold_split(x, n_splits=5, shuffle=True, random_state=0):
     return fold_array(splitter, x)
 
 
+def group_kfold_split(groups, n_splits=5):
+    splitter = GroupKFold(n_splits)
+    return fold_array(splitter, groups, groups, groups=groups)
+
+
 def stratified_kfold_split(y, n_splits=5, shuffle=True, random_state=0):
     splitter = StratifiedKFold(n_splits, shuffle=shuffle, random_state=random_state)
     return fold_array(splitter, y, y)
